#
# spec file for package perl-common-sense
#
# Copyright (c) 2020 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           perl-common-sense
Version:        3.75
Release:        1.21
#Upstream: CHECK(Artistic-1.0 or GPL-1.0-or-later)
%define cpan_name common-sense
Summary:        Save a tree AND a kitten, use common::sense!
License:        GPL-1.0-or-later OR Artistic-1.0
Group:          Development/Libraries/Perl
Url:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/M/ML/MLEHMANN/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
# MANUAL
#BuildArch:     noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
%{perl_requires}

%description
   “Nothing is more fairly distributed than common sense: no one thinks
   he needs more of it than he already has.”

   – René Descartes

This module implements some sane defaults for Perl programs, as defined by
two typical (or not so typical - use your common sense) specimens of Perl
coders. In fact, after working out details on which warnings and strict
modes to enable and make fatal, we found that we (and our code written so
far, and others) fully agree on every option, even though we never used
warnings before, so it seems this module indeed reflects a "common" sense
among some long-time Perl coders.

The basic philosophy behind the choices made in common::sense can be
summarised as: "enforcing strict policies to catch as many bugs as
possible, while at the same time, not limiting the expressive power
available to the programmer".

Two typical examples of how this philosophy is applied in practise is the
handling of uninitialised and malloc warnings:

* _uninitialised_

'undef' is a well-defined feature of perl, and enabling warnings for using
it rarely catches any bugs, but considerably limits you in what you can do,
so uninitialised warnings are disabled.

* _malloc_

Freeing something twice on the C level is a serious bug, usually causing
memory corruption. It often leads to side effects much later in the program
and there are no advantages to not reporting this, so malloc warnings are
fatal by default.

Unfortunately, there is no fine-grained warning control in perl, so often
whole groups of useful warnings had to be excluded because of a single
useless warning (for example, perl puts an arbitrary limit on the length of
text you can match with some regexes before emitting a warning, making the
whole 'regexp' category useless).

What follows is a more thorough discussion of what this module does, and
why it does it, and what the advantages (and disadvantages) of this
approach are.

%prep
%setup -q -n %{cpan_name}-%{version}
find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
make %{?_smp_mflags}

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes README
%license LICENSE

%changelog
* Fri Apr  3 2020 <timueller+perl@suse.de>
- updated to 3.75
  see /usr/share/doc/packages/perl-common-sense/Changes
  3.75 Thu Apr  2 09:53:01 CEST 2020
  - make build (more) reproducible.
  - removed "portable" from the warnngs list, as 32 bit perls (as
    opposed to 32 bit platforms) are practically extinct and it
    warns about a weird subset of operations, i.e. 64 bit hex() is
    not ok, 64 bit addition is fine, makes no sense. Moreso, other
    than hex/oct etc. harassment, there is nothing in this category
    that could be otherwise useful.
* Thu Jul  2 2015 coolo@suse.com
- updated to 3.74
  see /usr/share/doc/packages/perl-common-sense/Changes
  3.74 Mon Jun 29 14:39:26 CEST 2015
  - the generated README file was empty.
* Tue Apr 14 2015 coolo@suse.com
- updated to 3.73
  see /usr/share/doc/packages/perl-common-sense/Changes
  3.73 Sat May 31 22:37:21 CEST 2014
  - remove "deprecated", as it turned out to be yet another time bomb
    as p5p don't care the least about backwards compatibility
    anymore (https://rt.perl.org/Public/Bug/Display.html?id=119123).
  - switching paths once more as this turned out to be a doc bug
    in eumm.  this should not affect anything though.
* Sun Aug  4 2013 coolo@suse.com
- updated to 3.72
  - install paths were wrong for current MakeMaker (reported
    by various people).
  - CPAN failed to parse the version number in 3.7, try to work
    around.
  - move pod to separate file, to further improve loading times.
  - make it arch-specific, adding a test that warns when an old
    version is still installed.
  - due to a logic glitch, warnings were not enabled at all on 5.16.
* Sat Jun 15 2013 coolo@suse.com
- updated to 3.6
  - work around more 5.16 breakage - $^H doesn't work as nicely as
    p5p make you to believe.
  - add features: unicode_strings current_sub fc evalbytes.
  - disable features: array_base.
* Wed May 23 2012 coolo@suse.com
- updated to 3.5
  - localise $^W, as this causes warnings with 5.16 when some lost
    soul uses -w. common::sense doesn't support $^W, but tries to
    shield module authors and programs from its ill effects. If you
    enable $^W, then you normally get to keep the pieces because you
    change semantics of other people's code.
* Fri Mar  4 2011 chris@computersalat.de
- update to 3.4
  - remove "regexp" category. this is rather painful as it's a large
    class, but unfortunately, somebody thought emitting a warning when
    you match more than 32kb of text is in some way useful, which
    spoils the whole category.
  - use META.json instead of META.yml - apparently YAML parsers don't
    actually exist.
- recreated by cpanspec 1.78.03
* Tue Nov 30 2010 coolo@novell.com
- switch to perl_requires macro
* Tue Jul  6 2010 chris@computersalat.de
- update tp 3.3
  - removed "exiting" category - this is too useful to create new
    control statements, and fails utterly with eval, as eval will
    catch the (fatal) warning itself. Kind of hurts, but this is
    just another warning category which is too broad and has to be
    disabled fully because of a minority of issues.
- noarch package
  o remove .packlist/perllocal.pod
* Fri Apr 16 2010 chris@computersalat.de
- update to 3.2
  - removed "substr" warning - while it overall is a good category,
    "substr '', 2" is entirely sensible.
- 3.1  Sat Apr  3 04:56:36 CEST 2010
  - removed "parenthesis" warning:
    sysread $fh, my $buf, -s $fh; # ok
    sysread $fh, my $buf, $size;  # warning
    Made no sense to me, especially as $size is in scope.
  - no longer hardcode warning/struct bits, calculate them at
    installation time, for when I will no longer be alive etc.
  - tweaked documentation.
- fixed perl-macros deps
* Mon Jan 18 2010 jw@novell.com
- update to 3.0, as suggested by JSON::XS
* Fri Sep  4 2009 chris@computersalat.de
- initial pkg 2.0
